@@ -8,14 +8,23 @@ logger = logging.getLogger(__name__)
 
 # https://daskhub.dev.ctaodc.ch/services/downloadservice/fetch/pnfs/cta.cscs.ch/lst/DL1/20230226/v0.9_calib12100/tailcut84
 
-hubbase = "http://hub:5000/services/downloadservice/fetch/"
+hubbase = "http://hub:5000"
+dsbase = urljoin(hubbase, "services/downloadservice/fetch/")
+
 
 def list_dir(url):
-    return [u.replace(hubbase, "") for u in requests.get(
-            urljoin(hubbase, "pnfs/cta.cscs.ch", url),
-            params = {'token': os.getenv("JUPYTERHUB_API_TOKEN")},
-            stream=True
-        ).json()['urls']]
+    fullurl = urljoin(urljoin(dsbase, "pnfs/cta.cscs.ch/"), url)
+    print(fullurl)
+    
+    r = requests.get(
+                fullurl,
+                params = {'token': os.getenv("JUPYTERHUB_API_TOKEN")},
+            )
+    try:
+        return [u.replace(dsbase, "") for u in r.json()['urls']]
+    except Exception as e:
+        return r.text[:1000]
+
 
 
 def fetch_and_save_file(url, fn=None):
@@ -26,7 +35,7 @@ def fetch_and_save_file(url, fn=None):
 
     with open(fn, "wb") as outf:
         with requests.get(
-            urljoin(hubbase, "pnfs/cta.cscs.ch", url),
+            urljoin(dsbase, "pnfs/cta.cscs.ch", url),
             params = {'token': os.getenv("JUPYTERHUB_API_TOKEN")},
             stream=True
         ) as f:          
